pub type DecisionTrace = Vec<TranspilerDecision>;Expand description
Ordered trace of decisions from a single transpilation run.
Aliased Type
pub struct DecisionTrace { /* private fields */ }pub type DecisionTrace = Vec<TranspilerDecision>;Ordered trace of decisions from a single transpilation run.
pub struct DecisionTrace { /* private fields */ }