Module stdlib

Module stdlib 

Standard library function mappings

This module provides support for stdlib functions that are transpiled to POSIX shell runtime functions.

Re-exports

pub use crate::stdlib_metadata::StdlibFunction;
pub use crate::stdlib_metadata::STDLIB_FUNCTIONS;

Functions

get_shell_function_name
Get the shell function name for a stdlib function
is_stdlib_function
Check if a function name is a stdlib function