Standard library function mappings
This module provides support for stdlib functions that are transpiled to POSIX shell runtime functions.
Re-exports
pub use crate::stdlib_metadata::StdlibFunction;pub use crate::stdlib_metadata::STDLIB_FUNCTIONS;
Functions
- get_
shell_ function_ name - Get the shell function name for a stdlib function
- is_
stdlib_ function - Check if a function name is a stdlib function